`xotl.tools.fp`:mod: -- Functional Programming in Python
========================================================

.. automodule:: xotl.tools.fp
   :synopsis: In Functional Programming a problem is decomposed into a set of
              functions.
   :members:

--------------

Ideally, a function only takes inputs and produce outputs, and doesn't have
any internal state that affects the output produced for a given input (like in
Haskell).


Contents
--------

.. toctree::
   :maxdepth: 1
   :glob:

   fp/*
